@@ -28,7 +28,7 @@
 //! cargo run --example ping
 //! ```
 //!
-//! It will print the PeerId and the listening address, e.g. `Listening on
+//! It will print the PeerId and the listening addresses, e.g. `Listening on
 //! "/ip4/0.0.0.0/tcp/24915"`
 //!
 //! In the second terminal window, start a new instance of the example with:
@@ -42,9 +42,8 @@
 
 use futures::executor::block_on;
 use futures::prelude::*;
-use libp2p::ping::{Ping, PingConfig};
 use libp2p::swarm::{Swarm, SwarmEvent};
-use libp2p::{identity, PeerId};
+use libp2p::{identity, ping, Multiaddr, PeerId};
 use std::error::Error;
 use std::task::Poll;
 
@@ -60,7 +59,7 @@ fn main() -> Result<(), Box<dyn Error>> {
     // For illustrative purposes, the ping protocol is configured to
     // keep the connection alive, so a continuous sequence of pings
     // can be observed.
-    let behaviour = Ping::new(PingConfig::new().with_keep_alive(true));
+    let behaviour = ping::Behaviour::new(ping::Config::new().with_keep_alive(true));
 
     let mut swarm = Swarm::new(transport, behaviour, local_peer_id);
 
@@ -71,15 +70,15 @@ fn main() -> Result<(), Box<dyn Error>> {
     // Dial the peer identified by the multi-address given as the second
     // command-line argument, if any.
     if let Some(addr) = std::env::args().nth(1) {
-        let remote = addr.parse()?;
-        swarm.dial_addr(remote)?;
+        let remote: Multiaddr = addr.parse()?;
+        swarm.dial(remote)?;
         println!("Dialed {}", addr)
     }
 
     block_on(future::poll_fn(move |cx| loop {
         match swarm.poll_next_unpin(cx) {
             Poll::Ready(Some(event)) => match event {
-                SwarmEvent::NewListenAddr{ address, .. } => println!("Listening on {:?}", address),
+                SwarmEvent::NewListenAddr { address, .. } => println!("Listening on {:?}", address),
                 SwarmEvent::Behaviour(event) => println!("{:?}", event),
                 _ => {}
             },
